/* localetest - locale language test program

   Written by Harry Sintonen.
    2003 by Harry Sintonen.
*/

#include <libraries/locale.h>

#include <proto/exec.h>
#include <proto/dos.h>
#include <proto/locale.h>

#include <string.h>

int main(int argc, char **argv)
{
  struct Library *LocaleBase;
  struct Locale *loc;
  LONG x;
  UBYTE *p;
  UBYTE *casestr = "abcxyz123ABCZYZ123";
  UBYTE *isstr = " \tabc123ABC!@#,.-";
  UBYTE c;
  UBYTE s[3];
  UBYTE buf[128];

  LocaleBase = OpenLibrary("locale.library", 38);
  if (!LocaleBase)
  {
	Printf("Can't open locale.library V38+\n");
	return 20;
  }

  loc = OpenLocale(argc == 2 ? argv[1] : NULL);
  if (!loc)
  {
	Printf("Could not open %s locale!\n", (LONG) (argc == 2 ? argv[1] : "default"));
	CloseLibrary(LocaleBase);
	return 10;
  }

  Printf("ConvToLower: \"");
  for (p = casestr; (c = *p); p++)
  {
	Printf("%lc", ConvToLower(loc, c));
  }
  Printf("\"\n");
  Printf("ConvToUpper: \"");
  for (p = casestr; (c = *p); p++)
  {
	Printf("%lc", ConvToUpper(loc, c));
  }
  Printf("\"\n");

  Printf("GetLocaleStr:\n");
  for (x = 1; x < MAXSTRMSG; x++)
  {
	Printf("%02ld: \"%s\"\n", x, (LONG) GetLocaleStr(loc, x));
  }

  Printf("IsXXXX:\n");
  Printf("char   AlNum Alpha Cntrl Digit Graph Lower Print Punct Space Upper XDigit\n");
  s[2] = '\0';
  for (p = isstr; (c = *p); p++)
  {
	if (c < 32)
	{
	  s[0] = '^';
	  s[1] = '@' + c;
	}
	else
	{
	  s[0] = c;
	  s[1] = '\0';
	}
	Printf("%-3ld %2s ", c, (LONG) s);
	Printf("%-5ld ", IsAlNum(loc, c));
	Printf("%-5ld ", IsAlpha(loc, c));
	Printf("%-5ld ", IsCntrl(loc, c));
	Printf("%-5ld ", IsDigit(loc, c));
	Printf("%-5ld ", IsGraph(loc, c));
	Printf("%-5ld ", IsLower(loc, c));
	Printf("%-5ld ", IsPrint(loc, c));
	Printf("%-5ld ", IsPunct(loc, c));
	Printf("%-5ld ", IsSpace(loc, c));
	Printf("%-5ld ", IsUpper(loc, c));
	Printf("%-5ld\n", IsXDigit(loc, c));
  }

  memset(buf, '', sizeof(buf) - 1); buf[sizeof(buf) - 1] = '\0';
  x = StrConvert(loc, casestr, buf, sizeof(buf) - 1, SC_ASCII);
  Printf("StrConvert SC_ASCII:    %ld \"%s\"\n", x, (LONG) buf);
  x = StrConvert(loc, casestr, buf, sizeof(buf) - 1, SC_COLLATE1);
  Printf("StrConvert SC_COLLATE1: %ld \"%s\"\n", x, (LONG) buf);
  x = StrConvert(loc, casestr, buf, sizeof(buf) - 1, SC_COLLATE2);
  Printf("StrConvert SC_COLLATE2: %ld \"%s\"\n", x, (LONG) buf);

  /* This reveals some buggy languages, like suomi.language */
  memset(buf, '', sizeof(buf) - 1); buf[sizeof(buf) - 1] = '\0';
  x = StrConvert(loc, casestr, buf, 5/*sizeof(buf) - 1*/, SC_COLLATE2);
  Printf("StrConvert SC_COLLATE2: %ld \"%s\"\n", x, (LONG) buf);

  x = StrnCmp(loc, "abc", "ABC", 6, SC_ASCII);
  Printf("StrnCmp SC_ASCII:    %ld\n", x);
  x = StrnCmp(loc, "", "aoa", 3, SC_COLLATE1);
  Printf("StrnCmp SC_COLLATE1: %ld\n", x);
  x = StrnCmp(loc, "", "aoa", 3, SC_COLLATE2);
  Printf("StrnCmp SC_COLLATE2: %ld\n", x);

  CloseLocale(loc);
  CloseLibrary(LocaleBase);
  return 0;
}
